"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const errors_1 = require("@oclif/errors");
const yaml_1 = require("@stoplight/yaml");
const definition_1 = require("../definition");
const command_1 = (0, tslib_1.__importDefault)(require("../command"));
const flagsBuilder = (0, tslib_1.__importStar)(require("../flags"));
const args_1 = require("../args");
const cli_1 = require("../cli");
const overlay_1 = require("../core/overlay");
class Overlay extends command_1.default {
    async run() {
        const { args } = this.parse(Overlay);
        const newDefinition = await this.applyOverlay(args.FILE, args.OVERLAY_FILE);
        cli_1.cli.log(newDefinition);
        return;
    }
    async applyOverlay(file, overlayFile) {
        const api = await definition_1.API.load(file);
        const definition = api.definition;
        this.d(`${file} looks like an ${api.specName} spec version ${api.version}`);
        const overlay = await definition_1.API.load(overlayFile);
        const overlayDefinition = overlay.definition;
        if (!definition_1.API.isOpenAPIOverlay(overlayDefinition)) {
            throw new errors_1.CLIError(`${overlayFile} does not look like an OpenAPI overlay`);
        }
        cli_1.cli.action.start("* Let's apply the overlay to the main definition");
        const newDefinition = (0, overlay_1.applyOverlay)(definition, overlayDefinition);
        cli_1.cli.action.stop();
        if (file.endsWith('.json')) {
            return JSON.stringify(newDefinition);
        }
        else {
            return (0, yaml_1.safeStringify)(newDefinition);
        }
    }
}
exports.default = Overlay;
Overlay.description = 'Apply an OpenAPI specified overlay to your API definition.';
Overlay.examples = [
    `$ bump overlay DEFINITION_FILE OVERLAY_FILE
`,
];
Overlay.flags = {
    help: flagsBuilder.help({ char: 'h' }),
};
Overlay.args = [args_1.fileArg, args_1.overlayFileArg];
