import $RefParser from '@apidevtools/json-schema-ref-parser';
import { JSONSchema4, JSONSchema4Object, JSONSchema4Array, JSONSchema6, JSONSchema6Object, JSONSchema7 } from 'json-schema';
declare type SpecSchema = JSONSchema4 | JSONSchema6 | JSONSchema7;
declare class SupportedFormat {
    static readonly openapi: Record<string, SpecSchema>;
    static readonly asyncapi: Record<string, SpecSchema>;
}
declare class API {
    readonly location: string;
    readonly rawDefinition: string;
    readonly definition: APIDefinition;
    readonly references: APIReference[];
    readonly version: string;
    readonly specName: string;
    readonly spec?: SpecSchema;
    constructor(location: string, $refs: $RefParser.$Refs);
    getSpec(definition: APIDefinition): SpecSchema;
    getSpecName(definition: APIDefinition): string;
    getVersion(definition: APIDefinition): string;
    versionWithoutPatch(): string;
    resolveRelativeLocation(absPath: string): string;
    resolveContent($refs: $RefParser.$Refs): [string, APIDefinition];
    static isOpenAPI(definition: JSONSchema4Object | JSONSchema6Object): definition is OpenAPI;
    static isAsyncAPI(definition: JSONSchema4Object | JSONSchema6Object): definition is AsyncAPI;
    static isOpenAPIOverlay(definition: JSONSchema4Object | JSONSchema6Object): definition is OpenAPIOverlay;
    extractDefinition(): [string, APIReference[]];
    static load(path: string): Promise<API>;
}
declare type APIReference = {
    location: string;
    content: string;
};
declare type APIDefinition = OpenAPI | AsyncAPI | OpenAPIOverlay;
declare type OpenAPI = JSONSchema4Object & {
    readonly openapi?: string;
    readonly swagger?: string;
    readonly info: string;
};
declare type OpenAPIOverlay = JSONSchema4Object & {
    readonly overlay: string;
    readonly info: string;
    readonly actions: JSONSchema4Array;
};
declare type AsyncAPI = JSONSchema4Object & {
    readonly asyncapi: string;
    readonly info: string;
};
export { API, APIDefinition, OpenAPIOverlay, SupportedFormat };
